/// <reference types="node" />
import sqlite from 'better-sqlite3';
import type { Store, FactoryStore, Config } from 'cache-manager';
export declare const serializers: {
    json: {
        serialize: (o: unknown) => string;
        deserialize: (p: string) => any;
    };
    cbor: {
        serialize: (o: unknown) => Buffer;
        deserialize: (p: any) => any;
    };
};
export interface SqliteCacheAdapterOptions extends Config {
    name?: string;
    path?: string;
    onReady?: (db: sqlite.Database) => any;
    serializer?: 'json' | 'cbor' | {
        serialize: typeof serializers['json']['serialize'] | typeof serializers['cbor']['serialize'];
        deserialize: typeof serializers['json']['deserialize'] | typeof serializers['cbor']['deserialize'];
    };
    sqliteOptions?: sqlite.Options;
}
export declare class SqliteCacheAdapter implements Store {
    #private;
    db: sqlite.Database;
    /**
     * @param name - name of key-value space
     * @param path - path of database file
     * @param options - options for opening database
     */
    constructor(options: SqliteCacheAdapterOptions);
    mget(...args: string[]): Promise<any[]>;
    get<T>(key: string): Promise<T | undefined>;
    mset(args: [string, unknown][], keyTTL?: number): Promise<void>;
    set<T>(key: string, value: T, ttl?: number): Promise<void>;
    mdel(...args: string[]): Promise<void>;
    del(key: string): Promise<void>;
    reset(): Promise<void>;
    ttl(key: string): Promise<number>;
    keys(pattern?: string): Promise<string[]>;
}
declare const sqliteStore: FactoryStore<SqliteCacheAdapter, SqliteCacheAdapterOptions>;
export default sqliteStore;
